magneticalc.QtWidgets2.QDoubleSpinBox2.QDoubleSpinBox2

# ``magneticalc`.`QtWidgets2`.`QDoubleSpinBox2`.`QDoubleSpinBox2``

class documentation

`class QDoubleSpinBox2(QDoubleSpinBox):`

Constructor: `QDoubleSpinBox2(gui, minimum, maximum, step, ...)`

View In Hierarchy

QDoubleSpinBox2 class.

Method | `__init__` | Initializes a floating-point spinbox.

def __init__(self, gui: `GUI`, minimum: `float`, maximum: `float`, step: `float`, precision: `int`, value: `int`, value_changed: `Callable`):

Initializes a floating-point spinbox.

Parameters
gui: `GUI` | GUI
minimum: `float` | Minimum value
maximum: `float` | Maximum value
step: `float` | Step
precision: `int` | Precision
value: `int` | Initial value
value_changed: `Callable` | Value changed callback